@@ -1,5 +1,6 @@
 from corm.constants import DATETIME_FORMAT
 from corm.datatypes import Transliterator
+from corm.annotations import Set
 
 from datetime import datetime
 
@@ -13,4 +14,5 @@ DT_MAP = {
     str: Transliterator('TEXT', lambda x: str(x), lambda x: str(x)),
     int: Transliterator('BIGINT', lambda x: int(x), lambda x: int(x)),
     datetime: Transliterator('TIMESTAMP', datetime__python_to_cql, datetime__cql_to_python, True),
+    Set: Transliterator('SET<text>', lambda x: [i for i in x], lambda x: x),
 }
